@@ -2225,8 +2225,8 @@ on_help_about (GtkAction  *action,
 	                       "copyright", copyright,
 	                       "comments", _ (comments),
 	                       "version", VERSION,
-	                       "website", "http://trac.novowork.com/gitg",
-	                       "website-label", "trac.novowork.com/gitg",
+	                       "website", PACKAGE_URL,
+	                       "website-label", "gitg homepage",
 	                       "logo", pixbuf,
 	                       "license-type", GTK_LICENSE_GPL_2_0,
 	                       NULL);
