@@ -101,8 +101,7 @@ collapsed_lane_new (LaneContainer *container)
 static void
 free_lanes (GitgLanes *lanes)
 {
-	g_slist_foreach (lanes->priv->lanes, (GFunc)lane_container_free, NULL);
-	g_slist_free (lanes->priv->lanes);
+	g_slist_free_full (lanes->priv->lanes, (GDestroyNotify)lane_container_free);
 
 	lanes->priv->lanes = NULL;
 }
@@ -316,8 +315,7 @@ gitg_lanes_reset (GitgLanes *lanes)
 	free_lanes (lanes);
 	gitg_color_reset ();
 
-	g_slist_foreach (lanes->priv->previous, (GFunc)gitg_revision_unref, NULL);
-	g_slist_free (lanes->priv->previous);
+	g_slist_free_full (lanes->priv->previous, (GDestroyNotify)gitg_revision_unref);
 
 	lanes->priv->previous = NULL;
 
