@@ -21,6 +21,7 @@
  */
 
 #include "gitg-line-parser.h"
+#include <libgitg/gitg-debug.h>
 
 #define GITG_LINE_PARSER_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE((object), GITG_TYPE_LINE_PARSER, GitgLineParserPrivate))
 
@@ -212,6 +213,8 @@ parse_lines (GitgLineParser *stream,
 			stream->priv->lines[i++] = g_strndup (ptr, newline - ptr);
 		}
 
+		gitg_debug (GITG_DEBUG_SHELL_OUTPUT, "%s", stream->priv->lines[i - 1]);
+
 		ptr = line_end;
 
 		if (i == stream->priv->buffer_size)
@@ -324,10 +327,7 @@ gitg_line_parser_constructed (GObject *object)
 
 	stream->priv->read_buffer = g_slice_alloc (sizeof (gchar) * (stream->priv->buffer_size + 1));
 
-	if (G_OBJECT_CLASS (gitg_line_parser_parent_class)->constructed)
-	{
-		G_OBJECT_CLASS (gitg_line_parser_parent_class)->constructed (object);
-	}
+	G_OBJECT_CLASS (gitg_line_parser_parent_class)->constructed (object);
 }
 
 static void start_read_lines (AsyncData *data);
